import pandas

# define conversion consts
# foot to metter const
ft_to_m = 0.3048
# short tonne to metric tonne const
st_to_t = 0.907184
# ounce to gram const
oz_to_g = 28.34952

# import imperial model
imperial_model = pandas.read_csv("imperial_model.csv")

# create metric model
metric_model = pandas.DataFrame(columns=['X', 'Y', 'Z'])

# set coordinates to metric model (foot to meter)
metric_model['X'] = imperial_model['X'] * ft_to_m
metric_model['Y'] = imperial_model['Y'] * ft_to_m
metric_model['Z'] = imperial_model['Z'] * ft_to_m

# set dimension to metric model (foot to meter)
metric_model['!DIM_X'] = imperial_model['DIM_X'] * ft_to_m
metric_model['!DIM_Y'] = imperial_model['DIM_Y'] * ft_to_m
metric_model['!DIM_Z'] = imperial_model['DIM_Z'] * ft_to_m

# set mass to metric model (short tonne to metric tonne)
metric_model['!MASS'] = imperial_model['MASS'] * st_to_t

# set volume to metric model (cubic metter)
metric_model['!VOLUME'] = metric_model['!DIM_X'] * metric_model['!DIM_Y'] * metric_model['!DIM_Z']

# set density to metric model (metric tonne per cubic metter)
metric_model['%DENSITY'] = metric_model['!MASS'] / metric_model['!VOLUME']

# set grades to metric model (ounces per short tonne to grams per metric tonne or ppm)
metric_model['@GRADE_AU'] = imperial_model['GRADE_AU'] * oz_to_g / st_to_t
metric_model['@GRADE_CU'] = imperial_model['GRADE_CU'] * oz_to_g / st_to_t

# set recovery values to metric model
metric_model['*REC_AU'] = imperial_model['REC_AU']
metric_model['*REC_CU'] = imperial_model['REC_CU']

# set economic values to metric model
metric_model['$PROCESS'] = imperial_model['PROCESS']
metric_model['$WASTE'] = imperial_model['WASTE']

# export metric model to csv
metric_model.to_csv("metric_model.csv", index = False)
